@@ -45,6 +45,9 @@
 /* Define to 1 if an external Eigen3 shared library have been found */
 #define HAVE_EIGEN3 1
 
+/* Define to 1 if an external x265 shared library have been found */
+#define HAVE_X265 1
+
 /* The Eigen3 version string, if found, or an empty string otherwise */
 #define EIGEN3_VERSION_STRING "3.3.7"
 
